package com.sooka.sponest.monitor.aidevicedept.service;

import com.sooka.sponest.monitor.aidevicedept.domain.CenterdataTAidevicedept;

import java.util.List;

/**
 * AI对应部门Service接口
 *
 * @author yy
 * @date 2022-09-01
 */
public interface ICenterdataTAidevicedeptService
{
    /**
     * 查询AI对应部门
     *
     * @param id AI对应部门主键
     * @return AI对应部门
     */
    public CenterdataTAidevicedept selectCenterdataTAidevicedeptById(String id);

    /**
     * 查询AI对应部门列表
     *
     * @param centerdataTAidevicedept AI对应部门
     * @return AI对应部门集合
     */
    public List<CenterdataTAidevicedept> selectCenterdataTAidevicedeptList(CenterdataTAidevicedept centerdataTAidevicedept);

    /**
     * 新增AI对应部门
     *
     * @param centerdataTAidevicedept AI对应部门
     * @return 结果
     */
    public int insertCenterdataTAidevicedept(CenterdataTAidevicedept centerdataTAidevicedept);

    /**
     * 修改AI对应部门
     *
     * @param centerdataTAidevicedept AI对应部门
     * @return 结果
     */
    public int updateCenterdataTAidevicedept(CenterdataTAidevicedept centerdataTAidevicedept);

    /**
     * 批量删除AI对应部门
     *
     * @param ids 需要删除的AI对应部门主键集合
     * @return 结果
     */
    public int deleteCenterdataTAidevicedeptByIds(String[] ids);

    /**
     * 删除AI对应部门信息
     *
     * @param id AI对应部门主键
     * @return 结果
     */
    public int deleteCenterdataTAidevicedeptById(String id);

    //根据设备code查询
    public List<CenterdataTAidevicedept> selectDeptByDeviceCode(String deviceCode);
}
