package com.sooka.sponest.monitor.aidevicedept.mapper;

import com.sooka.sponest.monitor.aidevicedept.domain.CenterdataTAidevicedept;
import com.sooka.sponest.monitor.aidevicedept.domain.CenterdataTAidevicedeptDTO;

import java.util.List;

/**
 * AI对应部门Mapper接口
 *
 * @author yy
 * @date 2022-09-01
 */
public interface CenterdataTAidevicedeptMapper
{
    /**
     * 查询AI对应部门
     *
     * @param id AI对应部门主键
     * @return AI对应部门
     */
     CenterdataTAidevicedept selectCenterdataTAidevicedeptById(String id);

    /**
     * 查询AI对应部门列表
     *
     * @param centerdataTAidevicedept AI对应部门
     * @return AI对应部门集合
     */
     List<CenterdataTAidevicedept> selectCenterdataTAidevicedeptList(CenterdataTAidevicedept centerdataTAidevicedept);

    /**
     * 新增AI对应部门
     *
     * @param centerdataTAidevicedept AI对应部门
     * @return 结果
     */
     int insertCenterdataTAidevicedept(CenterdataTAidevicedept centerdataTAidevicedept);

    /**
     * 修改AI对应部门
     *
     * @param centerdataTAidevicedept AI对应部门
     * @return 结果
     */
     int updateCenterdataTAidevicedept(CenterdataTAidevicedept centerdataTAidevicedept);

    /**
     * 删除AI对应部门
     *
     * @param id AI对应部门主键
     * @return 结果
     */
     int deleteCenterdataTAidevicedeptById(String id);

    /**
     * 批量删除AI对应部门
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteCenterdataTAidevicedeptByIds(String[] ids);

    /**
     * 根据摄像头ids批量删除AI对应部门
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteCenterdataTAidevicedeptByCameraIds(String[] ids);

    /**
     * 根据设备code查询
     *
     * @param deviceCode 设备code
     * @return 结果
     */
     List<CenterdataTAidevicedept> selectDeptByDeviceCode(String deviceCode);

    List<CenterdataTAidevicedeptDTO> getByDeviceCode(String deviceCode);

}
